# pyatoms

The goal of **pyatoms** (Python automated tools for materials screening) is to enable automated, high-throughput computational screening of materials.

Currently, **pyatoms** is still in the early stages of development, and its features are primarily based on the methods that my collaborators and I have accumulated during our research on battery materials.

In the future, we aim to continually enhance **pyatoms** with the goal of achieving **real** automated materials screening.

## Installation

**pyatoms** can be easily installed using the following command:

```sh
pip install pyatoms
```
